searchData={"items":[{"type":"behaviour","title":"OpentelemetryHoneycombSampler","doc":"Sampling for Honeycomb comes with some additional challenges. This library helps you sample with Honeycomb and takes care of all the messy details.\n\n- 💥 Honeycomb's `SampleRate` has its own format (`1/SampleRate` are sampled, where `SampleRate` is an integer and `> 0`). See below for an example.\n- 💥 Honeycomb multiplies your spans by `SampleRate` to arrive at an estimate of the total number (sampled and unsampled) of spans.\n- 💥 Honeycomb expects `SampleRate` to be set on child spans as well as parent spans. If you don't take care of this detail, then your child spans won't be multiplied by `SampleRate` and will therefore be underrepresented in your Honeycomb searches / dashboards.\n\nThis package provides a handy interface for sampling which is similar to how stock otel samplers work, but with all the messy details abstracted away. Simply pattern match on spans and set a sample rate.","ref":"OpentelemetryHoneycombSampler.html"},{"type":"behaviour","title":"Getting started - OpentelemetryHoneycombSampler","doc":"Install the package:\n\n```elixir\n# mix.exs\ndef deps do\n  [\n    {:opentelemetry_honeycomb_sampler, \"~> 1.0.0\"}\n  ]\nend\n```\n\nCreate a sampler module:\n\n```elixir\n# my_sampler.ex\n\ndefmodule MySampler do\n  @behaviour OpentelemetryHoneycombSampler\n\n  @impl OpentelemetryHoneycombSampler\n  def description(_config), do: \"MySampler\"\n\n  @impl OpentelemetryHoneycombSampler\n  def setup(_config), do: []\n\n  @impl OpentelemetryHoneycombSampler\n  def sample_rate(\n        _ctx,\n        _trace_id,\n        _links,\n        _span_name,\n        _span_kind,\n        _span_attrs,\n        _sampler_config\n      ) do\n    # 1 # all events will be sent\n    # 2 # 50% of events will be sent\n    # 3 # 33% of events will be sent\n    # 4 # 25% of events will be sent\n    1\n  end\nend\n```\n\nAdd OpentelemetryHoneycombSampler to your `config/config.exs` or similar:\n\n```elixir\n# config/config.exs\n\nconfig :opentelemetry,\n  :sampler,\n  {OpentelemetryHoneycombSampler, %{root: {MySampler, _my_config = %{}}}}\n```\n\nAnd that's all there is to it!","ref":"OpentelemetryHoneycombSampler.html#module-getting-started"},{"type":"behaviour","title":"A note about SampleRate - OpentelemetryHoneycombSampler","doc":"Make sure there is a catch-all function head at the very bottom of your file that returns the general sample rate that you would like to use.\n\nHoneycomb's sample rates are expressed as a positive integer N (1, 2, 3, 1000, etc). Their sample rate means \"1 in N events will be sampled\". In other words, if you return `20` from `should_sample/7`, then one in twenty, or 5% of your events, will eventually be sent to Honeycomb.\n\nA sample rate of 1, therefore, results in all of your events being sent to Honeycomb. This is as if you did not configure sampling at all.","ref":"OpentelemetryHoneycombSampler.html#module-a-note-about-samplerate"},{"type":"behaviour","title":"Thanks - OpentelemetryHoneycombSampler","doc":"Developed partially under contract at [Fairing.co](https://fairing.co).","ref":"OpentelemetryHoneycombSampler.html#module-thanks"},{"type":"callback","title":"OpentelemetryHoneycombSampler.description/1","doc":"","ref":"OpentelemetryHoneycombSampler.html#c:description/1"},{"type":"callback","title":"OpentelemetryHoneycombSampler.sample_rate/7","doc":"","ref":"OpentelemetryHoneycombSampler.html#c:sample_rate/7"},{"type":"callback","title":"OpentelemetryHoneycombSampler.setup/1","doc":"","ref":"OpentelemetryHoneycombSampler.html#c:setup/1"},{"type":"module","title":"OpentelemetryHoneycombSampler.AlwaysOnSampleRatePropagator","doc":"Propagate SampleRate so that counts of child spans are accurately shown in Honeycomb","ref":"OpentelemetryHoneycombSampler.AlwaysOnSampleRatePropagator.html"},{"type":"module","title":"OpentelemetryHoneycombSampler.Sampler","doc":"","ref":"OpentelemetryHoneycombSampler.Sampler.html"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,49]},"content_type":"text/markdown"}